package com.ruoyi.system.service.fgw;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.fgw.FgwJdap;
import com.ruoyi.system.domain.vo.JdapVo;

/**
 * 发改委_节点安排Service接口
 * 
 * @author ruoyi
 * @date 2023-04-11
 */
public interface IFgwJdapService 
{
    /**
     * 查询发改委_节点安排
     * 
     * @param id 发改委_节点安排主键
     * @return 发改委_节点安排
     */
    public FgwJdap selectFgwJdapById(Long id);

    /**
     * 查询发改委_节点安排列表
     * 
     * @param fgwJdap 发改委_节点安排
     * @return 发改委_节点安排集合
     */
    public List<FgwJdap> selectFgwJdapList(FgwJdap fgwJdap);

    /**
     * 新增发改委_节点安排
     * 
     * @param jdapVo 发改委_节点安排
     * @return 结果
     */
    public AjaxResult insertFgwJdap(JdapVo jdapVo);

    /**
     * 修改发改委_节点安排
     * 
     * @param fgwJdap 发改委_节点安排
     * @return 结果
     */
    public AjaxResult updateFgwJdap(FgwJdap fgwJdap);

    /**
     * 批量删除发改委_节点安排
     * 
     * @param ids 需要删除的发改委_节点安排主键集合
     * @return 结果
     */
    public int deleteFgwJdapByIds(Long[] ids);

    /**
     * 删除发改委_节点安排信息
     * 
     * @param id 发改委_节点安排主键
     * @return 结果
     */
    public int deleteFgwJdapById(Long id);

    int jdsh(String ids, String shyj,String shjg);

    AjaxResult cb(Long id);

    AjaxResult fjcb(Long id, String time, String name);

    AjaxResult sycb(List<Long> idList);
}
